@@ -1,6 +1,6 @@
 RunModel_GR5H <- function(InputsModel, RunOptions, Param) {
-  
-  
+
+
   ## Initialization of variables
   NParam <- 5
   FortranOutputs <- .FortranOutputs(GR = "GR5H")$GR
@@ -10,24 +10,24 @@ RunModel_GR5H <- function(InputsModel, RunOptions, Param) {
   } else {
     Imax <- -99
   }
-  
-  
+
+
   ## Arguments check
   if (!inherits(InputsModel, "InputsModel")) {
     stop("'InputsModel' must be of class 'InputsModel'")
-  }  
+  }
   if (!inherits(InputsModel, "hourly"     )) {
     stop("'InputsModel' must be of class 'hourly'     ")
-  }  
+  }
   if (!inherits(InputsModel, "GR"         )) {
     stop("'InputsModel' must be of class 'GR'         ")
-  }  
+  }
   if (!inherits(RunOptions, "RunOptions"  )) {
     stop("'RunOptions' must be of class 'RunOptions'  ")
-  }  
+  }
   if (!inherits(RunOptions, "GR"          )) {
     stop("'RunOptions' must be of class 'GR'          ")
-  }  
+  }
   if (!is.vector(Param) | !is.numeric(Param)) {
     stop("'Param' must be a numeric vector")
   }
@@ -35,7 +35,7 @@ RunModel_GR5H <- function(InputsModel, RunOptions, Param) {
     stop(paste("'Param' must be a vector of length ", NParam, " and contain no NA", sep = ""))
   }
   Param <- as.double(Param)
-  
+
   Param_X1X3_threshold <- 1e-2
   Param_X4_threshold   <- 0.5
   if (Param[1L] < Param_X1X3_threshold) {
@@ -49,35 +49,36 @@ RunModel_GR5H <- function(InputsModel, RunOptions, Param) {
   if (Param[4L] < Param_X4_threshold) {
     warning(sprintf("Param[4] (X4: unit hydrograph time constant [h]) < %.2f\n X4 set to %.2f", Param_X4_threshold, Param_X4_threshold))
     Param[4L] <- Param_X4_threshold
-  }     
-  
+  }
+
   ## Input data preparation
   if (identical(RunOptions$IndPeriod_WarmUp, 0L)) {
     RunOptions$IndPeriod_WarmUp <- NULL
   }
   IndPeriod1   <- c(RunOptions$IndPeriod_WarmUp, RunOptions$IndPeriod_Run)
   LInputSeries <- as.integer(length(IndPeriod1))
-  if ("all" %in% RunOptions$Outputs_Sim) { IndOutputs <- as.integer(1:length(FortranOutputs)) 
+  if ("all" %in% RunOptions$Outputs_Sim) {
+    IndOutputs <- as.integer(1:length(FortranOutputs))
   } else {
     IndOutputs <- which(FortranOutputs %in% RunOptions$Outputs_Sim)
   }
-  
+
   ## Output data preparation
   IndPeriod2     <- (length(RunOptions$IndPeriod_WarmUp)+1):LInputSeries
   ExportDatesR   <- "DatesR"   %in% RunOptions$Outputs_Sim
   ExportStateEnd <- "StateEnd" %in% RunOptions$Outputs_Sim
-  
+
   ## Use of IniResLevels
   if (!is.null(RunOptions$IniResLevels)) {
-    RunOptions$IniStates[1] <- RunOptions$IniResLevels[1]*Param[1] ### production store level (mm)
-    RunOptions$IniStates[2] <- RunOptions$IniResLevels[2]*Param[3] ### routing store level (mm)
+    RunOptions$IniStates[1] <- RunOptions$IniResLevels[1] * Param[1] ### production store level (mm)
+    RunOptions$IniStates[2] <- RunOptions$IniResLevels[2] * Param[3] ### routing store level (mm)
     if (IsIntStore) {
       RunOptions$IniStates[4] <- RunOptions$IniResLevels[4] * Imax ### interception store level (mm)
     }
   }
-  
+
   ## Call GR model Fortan
-  RESULTS <- .Fortran("frun_gr5h", PACKAGE = "airGR", 
+  RESULTS <- .Fortran("frun_gr5h", PACKAGE = "airGR",
                       ## inputs
                       LInputs = LInputSeries,                             ### length of input and output series
                       InputsPrecip = InputsModel$Precip[IndPeriod1],      ### input series of total precipitation [mm/h]
@@ -97,14 +98,14 @@ RunModel_GR5H <- function(InputsModel, RunOptions, Param) {
   RESULTS$StateEnd[round(RESULTS$StateEnd, 3) == -999.999] <- NA
   if (ExportStateEnd) {
     RESULTS$StateEnd[-3L] <- ifelse(RESULTS$StateEnd[-3L] < 0, 0, RESULTS$StateEnd[-3L]) ### remove negative values except for the ExpStore location
-    RESULTS$StateEnd <- CreateIniStates(FUN_MOD = RunModel_GR5H, InputsModel = InputsModel, 
-                                        ProdStore = RESULTS$StateEnd[1L], RoutStore = RESULTS$StateEnd[2L], ExpStore = NULL, 
-                                        IntStore = RESULTS$StateEnd[4L], 
-                                        UH1 = NULL, UH2 = RESULTS$StateEnd[(1:(40*24))+(7+20*24)], 
-                                        GCemaNeigeLayers = NULL, eTGCemaNeigeLayers = NULL, 
+    RESULTS$StateEnd <- CreateIniStates(FUN_MOD = RunModel_GR5H, InputsModel = InputsModel,
+                                        ProdStore = RESULTS$StateEnd[1L], RoutStore = RESULTS$StateEnd[2L], ExpStore = NULL,
+                                        IntStore = RESULTS$StateEnd[4L],
+                                        UH1 = NULL, UH2 = RESULTS$StateEnd[(1:(40*24))+(7+20*24)],
+                                        GCemaNeigeLayers = NULL, eTGCemaNeigeLayers = NULL,
                                         verbose = FALSE)
   }
-  
+
   ## Output data preparation
   ## OutputsModel only
   if (!ExportDatesR & !ExportStateEnd) {
@@ -113,30 +114,30 @@ RunModel_GR5H <- function(InputsModel, RunOptions, Param) {
   }
   ## DatesR and OutputsModel only
   if (ExportDatesR & !ExportStateEnd) {
-    OutputsModel <- c(list(InputsModel$DatesR[RunOptions$IndPeriod_Run]), 
+    OutputsModel <- c(list(InputsModel$DatesR[RunOptions$IndPeriod_Run]),
                       lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]))
     names(OutputsModel) <- c("DatesR", FortranOutputs[IndOutputs])
   }
   ## OutputsModel and StateEnd only
   if (!ExportDatesR & ExportStateEnd) {
-    OutputsModel <- c(lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]), 
+    OutputsModel <- c(lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]),
                       list(RESULTS$StateEnd))
     names(OutputsModel) <- c(FortranOutputs[IndOutputs], "StateEnd")
   }
   ## DatesR and OutputsModel and StateEnd
   if ((ExportDatesR & ExportStateEnd) | "all" %in% RunOptions$Outputs_Sim) {
-    OutputsModel <- c(list(InputsModel$DatesR[RunOptions$IndPeriod_Run]), 
-                      lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]), 
+    OutputsModel <- c(list(InputsModel$DatesR[RunOptions$IndPeriod_Run]),
+                      lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]),
                       list(RESULTS$StateEnd))
     names(OutputsModel) <- c("DatesR", FortranOutputs[IndOutputs], "StateEnd")
   }
-  
+
   ## End
-  rm(RESULTS) 
+  rm(RESULTS)
   class(OutputsModel) <- c("OutputsModel", "hourly", "GR")
   if (IsIntStore) {
     class(OutputsModel) <- c(class(OutputsModel), "interception")
   }
   return(OutputsModel)
-  
+
 }
