@@ -1,9 +1,9 @@
 # Execute Regression test by comparing RD files stored in folders /tests/tmp/ref and /tests/tmp/test
-Args = commandArgs(trailingOnly=TRUE)
+Args <- commandArgs(trailingOnly = TRUE)
 
 source("tests/testthat/helper_regression.R")
 
-lActions = list(
+lActions <- list(
   stable = StoreStableExampleResults,
   dev = StoreDevExampleResults,
   compare = CompareStableDev
@@ -15,7 +15,7 @@ if(Args %in% names(lActions)) {
   stop("This script should be run with one argument in the command line:\n",
        "`Rscript tests/regression_tests.R [stable|dev|compare]`.\n",
        "Available arguments are:\n",
-       "- stable: install stable version from CRAN, run and store examples\n", 
+       "- stable: install stable version from CRAN, run and store examples\n",
        "- dev: install dev version from current directory, run and store examples\n",
        "- compare: stored results of both versions")
 }
